==> test-objects-4.19.0-sources.jar: de/alpharogroup/test/objects/annotations/classes/AnnotatedTestClass.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.test.objects.annotations.classes;

import de.alpharogroup.test.objects.annotations.TestFieldAnnotation;
import de.alpharogroup.test.objects.annotations.TestMethodAnnotation;
import de.alpharogroup.test.objects.annotations.TestTypeAnnotation;

/**
 * The class {@link AnnotatedTestClass} is a class intended for use in unit tests.
 */
@TestTypeAnnotation("type test value")
public class AnnotatedTestClass
{

	/** The name. */
	@TestFieldAnnotation("name test value")
	private String name;

	/**
	 * Gets the fullname.
	 *
	 * @return the fullname
	 */
	@TestMethodAnnotation("method test value")
	private String getFullname()
	{
		return "fullname";
	}

}

==> test-objects-4.28-sources.jar: de/alpharogroup/test/objects/annotations/classes/AnnotatedTestClass.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.test.objects.annotations.classes;

import de.alpharogroup.test.objects.annotations.TestFieldAnnotation;
import de.alpharogroup.test.objects.annotations.TestMethodAnnotation;
import de.alpharogroup.test.objects.annotations.TestTypeAnnotation;

/**
 * The class {@link AnnotatedTestClass} is a class intended for use in unit tests.
 */
@TestTypeAnnotation("type test value")
public class AnnotatedTestClass
{

	/** The name. */
	@TestFieldAnnotation("name test value")
	private String name;

	/**
	 * Gets the fullname.
	 *
	 * @return the fullname
	 */
	@TestMethodAnnotation("method test value")
	public String getFullname()
	{
		return "fullname";
	}

}
